# circuitikz
- https://github.com/circuitikz/circuitikz
- License: GPL
- Dependency via _pyimpspec_.

# cvxopt
- https://github.com/cvxopt/cvxopt
- License: GPLv3 or later
- Dependency via _pyimpspec_.

# cvxpy
- https://github.com/cvxpy/cvxpy
- License: Apache License version 2.0
- Optional dependency.

# Dear PyGui
- https://github.com/hoffstadt/DearPyGui
- License: MIT
- Dependency.

# DRT-python-code
- https://github.com/akulikovsky/DRT-python-code
- License: GPLv3 or later
- _pyimpspec_ copied/ported code to implement calculation of the distribution of relaxation times (DRT).

# Elchemea Analytical
- https://www.elchemea.com/
- License: GPLv3 or later
- _pyimpspec_ copied/ported code to implement some circuit elements.

# impedance.py
- https://github.com/ECSHackWeek/impedance.py
- License: MIT
- _pyimpspec_ copied code to implement linear Kramers-Kronig tests using matrix solvers.

# lmfit
- https://github.com/lmfit/lmfit-py
- License: BSD 3-clause
- Dependency via _pyimpspec_.

# matplotlib
- https://github.com/matplotlib/matplotlib
- License: custom license
- Dependency via _pyimpspec_.

# numpy
- https://github.com/numpy/numpy
- License: BSD 3-clause
- Dependency.

# odfpy
- https://github.com/eea/odfpy
- License: GPLv2 or later
- Dependency via _pyimpspec_.

# openpyxl
- https://foss.heptapod.net/openpyxl/openpyxl
- License: MIT
- Dependency via _pyimpspec_.

# pandas
- https://github.com/pandas-dev/pandas
- License: BSD 3-clause
- Dependency.

# pyimpspec
- https://github.com/vyrjana/pyimpspec
- License: GPLv3 or later
- Dependency.

# pyDRTtools
- https://github.com/ciuccislab/pyDRTtools
- License: MIT
- _pyimpspec_ copied/ported code to implement calculation of the distribution of relaxation times (DRT).

# requests
- https://github.com/psf/requests
- License: Apache License v2.0
- Dependency.

# SchemDraw
- https://bitbucket.org/cdelker/schemdraw/
- License: MIT
- Dependency via _pyimpspec_.

# SciPy
- https://github.com/scipy/scipy
- License: BSD 3-clause
- Dependency via _pyimpspec_.

# SymPy
- https://github.com/sympy/sympy
- License: BSD 3-clause
- Dependency.

# tabulate
- https://github.com/astanin/python-tabulate
- License: MIT
- Dependency via _pyimpspec_.

# tol_colors
- https://personal.sron.nl/~pault/data/tol_colors.py
- License: BSD 3-clause
- Copied values for some colors.

# xdg
- https://github.com/srstevenson/xdg
- License: ISC
- Dependency.
